## 0.9.9.2 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 0.9.9.1 (2023-01-25)

Fix some stubtest complaints before they happen (#9585)

Add missing objects to various stubs

## 0.9.9 (2022-07-20)

Allowlist useless modules (#8340)

These are the ones I chose not to add from #8321

Fixes most of #8339

## 0.9.8 (2022-06-26)

Check missing definitions for several packages (#8167)

Co-authored-by: hauntsaninja <>

## 0.9.7 (2022-05-07)

Import generics from standard modules in all third-party stubs (#7791)

## 0.9.6 (2022-04-27)

Drop Python 2 support in third-party stubs (#7703)

## 0.9.5 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 0.9.3 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 0.9.2 (2021-10-15)

Use lowercase tuple where possible (#6170)

## 0.9.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 0.9.0 (2021-09-19)

Update third-party package versions (#5996)

